@@ -1,7 +1,8 @@
 from django.urls import path
+from django.urls import include
 
 from labeltree import views
 
 urlpatterns = [
-    path("list/", views.list, name="list"),
+    path('', include(views.router.urls)),
 ]
